@@ -3,11 +3,11 @@ package Data::Validation::Constraints;
 use namespace::autoclean;
 use charnames qw( :full );
 
-use Moo;
 use Data::Validation::Constants;
 use Regexp::Common    qw( number );
 use Scalar::Util      qw( blessed looks_like_number );
 use Unexpected::Types qw( Any Bool Int );
+use Moo;
 
 with q(Data::Validation::Utils);
 
@@ -23,7 +23,7 @@ has 'required'   => is => 'ro', isa => Bool;
 
 has 'value'      => is => 'ro', isa => Any;
 
-sub validate {
+sub validate_value {
    my ($self, $val) = @_; my $method = $self->method; my $class;
 
    return 0 if (not $val and $self->required);
@@ -32,17 +32,7 @@ sub validate {
 
    return $self->$method( $val ) if ($self->can( $method ));
 
-   return $self->_load_class( 'isValid', $method )->_validate( $val );
-}
-
-# Private methods
-sub _validate {
-   my $self = shift;
-
-   EXCEPTION_CLASS->throw( error => 'Method [_1] not overridden in class [_2]',
-                           args  => [ '_validate', blessed $self || $self ] );
-
-   return;
+   return $self->load_class( 'isValid', $method )->validate( $val );
 }
 
 # Builtin factory validation methods
@@ -139,7 +129,7 @@ Data::Validation::Constraints - Test data values for conformance with constraint
 
    $constraint_ref = Data::Validation::Constraints->new( %config );
 
-   $constraint_ref->validate( $value );
+   $constraint_ref->validate_value( $value );
 
 =head1 Description
 
@@ -187,7 +177,7 @@ Used by the L</isEqualTo> method as the other value in the comparison
 
 =head1 Subroutines/Methods
 
-=head2 validate
+=head2 validate_value
 
 Called by L<Data::Validation>::check_field this method implements
 tests for a null input value so that individual validation methods
@@ -195,7 +185,7 @@ don't have to. It calls either a built in validation method or
 L</_validate> which should have been overridden in a factory
 subclass. An exception is thrown if the data value is not acceptable
 
-=head2 _validate
+=head2 validate
 
 Should have been overridden in an external constraint subclass
 
@@ -210,6 +200,11 @@ Test to see if the supplied value is equal to C<< $self->value >>. Calls
 C<isValidNumber> on both values to determine the type of comparison
 to perform
 
+=head2 isHexadecimal
+
+Tests to see if the value matches the regular expression for a hexadecimal
+number
+
 =head2 isMandatory
 
 Null values are not allowed
