@@ -2,8 +2,8 @@ package Data::Validation::Constraints::Path;
 
 use namespace::autoclean;
 
-use Moo;
 use Data::Validation::Constants;
+use Moo;
 
 extends q(Data::Validation::Constraints);
 
@@ -11,9 +11,9 @@ EXCEPTION_CLASS->add_exception( 'ValidPath', {
    parents => [ 'Constraint' ],
    error   => 'Parameter [_1] value [_2] is not a valid pathname' } );
 
-around '_validate' => sub {
-   my ($orig, $self, $val) = @_; return $val =~ m{ [;&*{} ] }mx ? 0 : 1;
-};
+sub validate {
+   my ($self, $val) = @_; return $val =~ m{ [;&*{} ] }mx ? 0 : 1;
+}
 
 1;
 
