@@ -2,9 +2,9 @@ package Data::Validation::Constraints::URL;
 
 use namespace::autoclean;
 
-use Moo;
 use Data::Validation::Constants;
-use LWP::UserAgent;
+use HTTP::Tiny;
+use Moo;
 
 extends q(Data::Validation::Constraints);
 
@@ -12,16 +12,15 @@ EXCEPTION_CLASS->add_exception( 'ValidURL', {
    parents => [ 'Constraint' ],
    error   => 'Parameter [_1] value [_2] is not a valid URL' } );
 
-around '_validate' => sub {
-   my ($orig, $self, $val) = @_; my $ua = LWP::UserAgent->new();
+sub validate {
+   my ($self, $val) = @_;
 
    $val !~ m{ \A http: }mx and $val = "http://localhost${val}";
-   $ua->agent( 'isValidURL/0.1 '.$ua->agent );
 
-   my $res = $ua->request( HTTP::Request->new( GET => $val ) );
+   my $res = HTTP::Tiny->new->get( $val );
 
-   return $res->is_success() ? 1 : 0;
-};
+   return $res->{success} ? 1 : 0;
+}
 
 1;
 
